# SuperFastPython.com
# example of getting results for tasks as they are completed
from time import sleep
from random import random
from concurrent.futures import ProcessPoolExecutor
from concurrent.futures import as_completed

# task function to be executed in the process pool
def task(task_id):
    # generate a random value between 0 and 1
    value = random()
    # sleep for some number of seconds
    sleep(value * 10)
    # return a result
    return f'Task={task_id}: {value}'

# protect the entry point
if __name__ == '__main__':
    # start the process pool
    with ProcessPoolExecutor(10) as exe:
        # submit tasks and collect futures
        futures = [exe.submit(task, i) for i in range(10)]
        # process task results as they are available
        for future in as_completed(futures):
            # retrieve the result
            result = future.result()
            # report the result
            print(result)