# SuperFastPython.com
# example of adding a callback to a task in the process pool
from time import sleep
from concurrent.futures import ProcessPoolExecutor

# callback function to call when a task is completed
def handler(future):
    # report a message
    print('The custom callback was called.', flush=True)
    # get the result from the task
    print(f'Got: {future.result()}')

# task function to be executed in the process pool
def work():
    # sleep for a moment
    sleep(1)
    # report a message
    print('The task is done.', flush=True)
    # return a value
    return 100

# protect the entry point
if __name__ == '__main__':
    # create a process pool
    with ProcessPoolExecutor() as exe:
        # execute the task
        future = exe.submit(work)
        # add the custom callback
        future.add_done_callback(handler)
    # wait for the task to complete...